@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: packages_parser.c 29603 2005-07-31 16:10:46Z cjwatson $
+ * $Id: packages_parser.c 55489 2008-09-01 22:52:31Z cjwatson $
  */
 
 #include <config.h>
@@ -237,7 +237,7 @@ void di_packages_parser_read_name (data, fip, field_modifier, value, user_data)
   const di_parser_fieldinfo *fip __attribute__ ((unused));
   di_rstring *field_modifier __attribute__ ((unused));
   di_rstring *value;
-  void *user_data __attribute__ ((unused));
+  void *user_data;
 {
   internal_di_package_parser_data *parser_data = user_data;
   di_package *p;
